// MotorController.h
#ifndef MOTORCONTROLLER_H
#define MOTORCONTROLLER_H

#include <Arduino.h>

// Motor configuration structure
struct MotorConfig
{
    uint8_t minPWM;
    uint8_t maxPWM;
    bool inverted;
    int responseSpeed;
    static const int lookupTableSize = 10;
    uint8_t lookupTable[lookupTableSize];
};

class MotorController
{
private:
    int motorPWMPin;
    int currentSpeed;
    int targetSpeed;
    MotorConfig config;

    int applyDynamicResponse(int targetValue);
    void setPWM(uint8_t pwmValue);

public:
    MotorController(int motorPin);

    void maintain();
    void stopMotor();
    void setTargetSpeed(int targetSpeedPercent);
    int getSpeed() const;

    MotorConfig getConfig() const;
    void setConfig(const MotorConfig &newConfig);
    void loadDefaults();
};

#endif // MOTORCONTROLLER_H
